residuals.hybridModel: Extract Model Residuals
Description
Extract the model residuals from the hybridModel object.
Usage
# S3 method for hybridModel
residuals(object, individual = FALSE, ...)
Arguments
individual
If TRUE, return the residuals of the component models instead
of the residuals for the whole ensemble model.
...
Other arguments (ignored).
Value
The residuals of the ensemble or individual component models.